library(sp)
library(rgdal)
library(stringr)
library(tidyverse)
library(jsonlite)
library(maptools)
library(geojsonio)

# Lecture codes postaux <-> codes insee (! padding)
# https://raw.githubusercontent.com/Rudloff/french-postal-codes-api/master/insee.csv
read_csv2("insee.csv") %>%
  select(Codepos, insee = INSEE) %>%
  mutate(insee = insee %>% str_pad(5, "left", "0")) %>%
  distinct -> insee

# Lecture carte et join avec codes postaux (! Corse)
# http://osm13.openstreetmap.fr/~cquest/openfla/export/communes-20150101-100m-shp.zip
readOGR("communes", "communes-20150101-100m") -> communes
 communes@data %>%
  mutate(insee = insee %>% str_replace("2(A|B)", "20")) %>%
  left_join(insee) -> communes@data
 
rm(insee)

# Écriture shapefile avec codes postaux
communes <- communes[!is.na(communes$Codepos),]
#writeOGR(communes, "communes_byCP", "communes_byCP", driver = "ESRI Shapefile")

communes <- unionSpatialPolygons(communes, communes$Codepos)

# Conversion geojson
communes %>% geojson_list -> geojson

# Ajout bounds
test <- geojson
test$features <- test$features[28] # 2 polys
geojson$features %>%
  map(function(feat)
  {
    feat$geometry$coordinates %>%
    unlist(recursive = F) %>%
    unlist(recursive = F) %>%
    transpose %>%
    map(unlist, recursive =F) %>%
    map(range) -> feat$properties$bounds
    
    feat
  }) -> geojson$features


geojson_write(geojson, file = "communes.json")